@@ -1,12 +1,15 @@
 use std::iter::FusedIterator;
 
 pub use list::{all_modules, list_modules};
-pub(crate) use module::KnownModule;
+pub use module::KnownModule;
 pub use module::Module;
 pub use path::{SearchPath, SearchPathValidationError};
 pub use resolver::SearchPaths;
 pub(crate) use resolver::file_to_module;
-pub use resolver::{resolve_module, resolve_real_module};
+pub use resolver::{
+    resolve_module, resolve_module_confident, resolve_real_module, resolve_real_module_confident,
+    resolve_real_shadowable_module,
+};
 use ruff_db::system::SystemPath;
 
 use crate::Db;
