@@ -180,10 +180,11 @@ impl<'db, 'ast> Unpacker<'db, 'ast> {
 
     pub(crate) fn finish(mut self) -> UnpackResult<'db> {
         self.targets.shrink_to_fit();
+
         UnpackResult {
             diagnostics: self.context.finish(),
             targets: self.targets,
-            cycle_fallback_type: None,
+            cycle_recovery: None,
         }
     }
 }
@@ -196,7 +197,7 @@ pub(crate) struct UnpackResult<'db> {
     /// The fallback type for missing expressions.
     ///
     /// This is used only when constructing a cycle-recovery `UnpackResult`.
-    cycle_fallback_type: Option<Type<'db>>,
+    cycle_recovery: Option<Type<'db>>,
 }
 
 impl<'db> UnpackResult<'db> {
@@ -222,7 +223,7 @@ impl<'db> UnpackResult<'db> {
         self.targets
             .get(&expr.into())
             .copied()
-            .or(self.cycle_fallback_type)
+            .or(self.cycle_recovery)
     }
 
     /// Returns the diagnostics in this unpacking assignment.
@@ -230,11 +231,25 @@ impl<'db> UnpackResult<'db> {
         &self.diagnostics
     }
 
-    pub(crate) fn cycle_initial(cycle_fallback_type: Type<'db>) -> Self {
+    pub(crate) fn cycle_initial(cycle_recovery: Type<'db>) -> Self {
         Self {
             targets: FxHashMap::default(),
             diagnostics: TypeCheckDiagnostics::default(),
-            cycle_fallback_type: Some(cycle_fallback_type),
+            cycle_recovery: Some(cycle_recovery),
         }
     }
+
+    pub(crate) fn cycle_normalized(
+        mut self,
+        db: &'db dyn Db,
+        previous_cycle_result: &UnpackResult<'db>,
+        cycle: &salsa::Cycle,
+    ) -> Self {
+        for (expr, ty) in &mut self.targets {
+            let previous_ty = previous_cycle_result.expression_type(*expr);
+            *ty = ty.cycle_normalized(db, previous_ty, cycle);
+        }
+
+        self
+    }
 }
