@@ -6,8 +6,6 @@ use crate::server::api::LSPResult;
 use crate::server::api::traits::{NotificationHandler, SyncNotificationHandler};
 use crate::session::Session;
 use crate::session::client::Client;
-use crate::system::AnySystemPath;
-use ty_project::watch::ChangeEvent;
 
 pub(crate) struct DidCloseNotebookHandler;
 
@@ -30,19 +28,12 @@ impl SyncNotificationHandler for DidCloseNotebookHandler {
             .document_handle(&uri)
             .with_failure_code(lsp_server::ErrorCode::InternalError)?;
 
-        let path = document.to_file_path().into_owned();
-
-        document
+        // We don't need to call publish any diagnostics because we clear
+        // the diagnostics when closing the corresponding cell documents.
+        let _ = document
             .close(session)
             .with_failure_code(lsp_server::ErrorCode::InternalError)?;
 
-        if let AnySystemPath::SystemVirtual(virtual_path) = &path {
-            session.apply_changes(
-                &path,
-                vec![ChangeEvent::DeletedVirtual(virtual_path.clone())],
-            );
-        }
-
         Ok(())
     }
 }
