@@ -9,8 +9,8 @@ use crate::TestServerBuilder;
 #[test]
 fn empty_workspace_folders() -> Result<()> {
     let server = TestServerBuilder::new()?
-        .build()?
-        .wait_until_workspaces_are_initialized()?;
+        .build()
+        .wait_until_workspaces_are_initialized();
 
     let initialization_result = server.initialization_result().unwrap();
 
@@ -24,8 +24,8 @@ fn single_workspace_folder() -> Result<()> {
     let workspace_root = SystemPath::new("foo");
     let server = TestServerBuilder::new()?
         .with_workspace(workspace_root, None)?
-        .build()?
-        .wait_until_workspaces_are_initialized()?;
+        .build()
+        .wait_until_workspaces_are_initialized();
 
     let initialization_result = server.initialization_result().unwrap();
 
@@ -47,12 +47,12 @@ fn workspace_diagnostic_registration_without_configuration() -> Result<()> {
         .with_workspace(workspace_root, None)?
         .enable_workspace_configuration(false)
         .enable_diagnostic_dynamic_registration(true)
-        .build()?;
+        .build();
 
     // No need to wait for workspaces to initialize as the client does not support workspace
     // configuration.
 
-    let (_, params) = server.await_request::<RegisterCapability>()?;
+    let (_, params) = server.await_request::<RegisterCapability>();
     let [registration] = params.registrations.as_slice() else {
         panic!(
             "Expected a single registration, got: {:#?}",
@@ -90,12 +90,12 @@ fn open_files_diagnostic_registration_without_configuration() -> Result<()> {
         .with_workspace(workspace_root, None)?
         .enable_workspace_configuration(false)
         .enable_diagnostic_dynamic_registration(true)
-        .build()?;
+        .build();
 
     // No need to wait for workspaces to initialize as the client does not support workspace
     // configuration.
 
-    let (_, params) = server.await_request::<RegisterCapability>()?;
+    let (_, params) = server.await_request::<RegisterCapability>();
     let [registration] = params.registrations.as_slice() else {
         panic!(
             "Expected a single registration, got: {:#?}",
@@ -131,10 +131,10 @@ fn workspace_diagnostic_registration_via_initialization() -> Result<()> {
         )
         .with_workspace(workspace_root, None)?
         .enable_diagnostic_dynamic_registration(true)
-        .build()?
-        .wait_until_workspaces_are_initialized()?;
+        .build()
+        .wait_until_workspaces_are_initialized();
 
-    let (_, params) = server.await_request::<RegisterCapability>()?;
+    let (_, params) = server.await_request::<RegisterCapability>();
     let [registration] = params.registrations.as_slice() else {
         panic!(
             "Expected a single registration, got: {:#?}",
@@ -170,10 +170,10 @@ fn open_files_diagnostic_registration_via_initialization() -> Result<()> {
         )
         .with_workspace(workspace_root, None)?
         .enable_diagnostic_dynamic_registration(true)
-        .build()?
-        .wait_until_workspaces_are_initialized()?;
+        .build()
+        .wait_until_workspaces_are_initialized();
 
-    let (_, params) = server.await_request::<RegisterCapability>()?;
+    let (_, params) = server.await_request::<RegisterCapability>();
     let [registration] = params.registrations.as_slice() else {
         panic!(
             "Expected a single registration, got: {:#?}",
@@ -209,10 +209,10 @@ fn workspace_diagnostic_registration() -> Result<()> {
             Some(ClientOptions::default().with_diagnostic_mode(DiagnosticMode::Workspace)),
         )?
         .enable_diagnostic_dynamic_registration(true)
-        .build()?
-        .wait_until_workspaces_are_initialized()?;
+        .build()
+        .wait_until_workspaces_are_initialized();
 
-    let (_, params) = server.await_request::<RegisterCapability>()?;
+    let (_, params) = server.await_request::<RegisterCapability>();
     let [registration] = params.registrations.as_slice() else {
         panic!(
             "Expected a single registration, got: {:#?}",
@@ -248,10 +248,10 @@ fn open_files_diagnostic_registration() -> Result<()> {
             Some(ClientOptions::default().with_diagnostic_mode(DiagnosticMode::OpenFilesOnly)),
         )?
         .enable_diagnostic_dynamic_registration(true)
-        .build()?
-        .wait_until_workspaces_are_initialized()?;
+        .build()
+        .wait_until_workspaces_are_initialized();
 
-    let (_, params) = server.await_request::<RegisterCapability>()?;
+    let (_, params) = server.await_request::<RegisterCapability>();
     let [registration] = params.registrations.as_slice() else {
         panic!(
             "Expected a single registration, got: {:#?}",
@@ -291,11 +291,11 @@ def foo() -> str:
         .with_workspace(workspace_root, None)?
         .enable_pull_diagnostics(true)
         .with_file(foo, foo_content)?
-        .build()?
-        .wait_until_workspaces_are_initialized()?;
+        .build()
+        .wait_until_workspaces_are_initialized();
 
-    server.open_text_document(foo, &foo_content, 1);
-    let hover = server.hover_request(foo, Position::new(0, 5))?;
+    server.open_text_document(foo, foo_content, 1);
+    let hover = server.hover_request(foo, Position::new(0, 5));
 
     assert!(
         hover.is_none(),
@@ -323,11 +323,11 @@ def foo() -> str:
         )?
         .enable_pull_diagnostics(true)
         .with_file(foo, foo_content)?
-        .build()?
-        .wait_until_workspaces_are_initialized()?;
+        .build()
+        .wait_until_workspaces_are_initialized();
 
-    server.open_text_document(foo, &foo_content, 1);
-    let hover = server.hover_request(foo, Position::new(0, 5))?;
+    server.open_text_document(foo, foo_content, 1);
+    let hover = server.hover_request(foo, Position::new(0, 5));
 
     assert!(
         hover.is_none(),
@@ -364,18 +364,18 @@ def bar() -> str:
         .enable_pull_diagnostics(true)
         .with_file(foo, foo_content)?
         .with_file(bar, bar_content)?
-        .build()?
-        .wait_until_workspaces_are_initialized()?;
+        .build()
+        .wait_until_workspaces_are_initialized();
 
-    server.open_text_document(foo, &foo_content, 1);
-    let hover_foo = server.hover_request(foo, Position::new(0, 5))?;
+    server.open_text_document(foo, foo_content, 1);
+    let hover_foo = server.hover_request(foo, Position::new(0, 5));
     assert!(
         hover_foo.is_none(),
         "Expected no hover information for workspace A, got: {hover_foo:?}"
     );
 
-    server.open_text_document(bar, &bar_content, 1);
-    let hover_bar = server.hover_request(bar, Position::new(0, 5))?;
+    server.open_text_document(bar, bar_content, 1);
+    let hover_bar = server.hover_request(bar, Position::new(0, 5));
     assert!(
         hover_bar.is_some(),
         "Expected hover information for workspace B, got: {hover_bar:?}"
@@ -394,10 +394,10 @@ fn unknown_initialization_options() -> Result<()> {
         .with_initialization_options(
             ClientOptions::default().with_unknown([("bar".to_string(), Value::Null)].into()),
         )
-        .build()?
-        .wait_until_workspaces_are_initialized()?;
+        .build()
+        .wait_until_workspaces_are_initialized();
 
-    let show_message_params = server.await_notification::<ShowMessage>()?;
+    let show_message_params = server.await_notification::<ShowMessage>();
 
     insta::assert_json_snapshot!(show_message_params, @r#"
     {
@@ -419,10 +419,10 @@ fn unknown_options_in_workspace_configuration() -> Result<()> {
             workspace_root,
             Some(ClientOptions::default().with_unknown([("bar".to_string(), Value::Null)].into())),
         )?
-        .build()?
-        .wait_until_workspaces_are_initialized()?;
+        .build()
+        .wait_until_workspaces_are_initialized();
 
-    let show_message_params = server.await_notification::<ShowMessage>()?;
+    let show_message_params = server.await_notification::<ShowMessage>();
 
     insta::assert_json_snapshot!(show_message_params, @r#"
     {
@@ -443,10 +443,10 @@ fn register_rename_capability_when_enabled() -> Result<()> {
         .with_workspace(workspace_root, None)?
         .with_initialization_options(ClientOptions::default().with_experimental_rename(true))
         .enable_rename_dynamic_registration(true)
-        .build()?
-        .wait_until_workspaces_are_initialized()?;
+        .build()
+        .wait_until_workspaces_are_initialized();
 
-    let (_, params) = server.await_request::<RegisterCapability>()?;
+    let (_, params) = server.await_request::<RegisterCapability>();
     let [registration] = params.registrations.as_slice() else {
         panic!(
             "Expected a single registration, got: {:#?}",
@@ -477,8 +477,8 @@ fn rename_available_without_dynamic_registration() -> Result<()> {
         .with_workspace(workspace_root, None)?
         .with_initialization_options(ClientOptions::default().with_experimental_rename(true))
         .enable_rename_dynamic_registration(false)
-        .build()?
-        .wait_until_workspaces_are_initialized()?;
+        .build()
+        .wait_until_workspaces_are_initialized();
 
     let initialization_result = server.initialization_result().unwrap();
     insta::assert_json_snapshot!(initialization_result.capabilities.rename_provider, @r#"
@@ -500,8 +500,8 @@ fn not_register_rename_capability_when_disabled() -> Result<()> {
         .with_workspace(workspace_root, None)?
         .with_initialization_options(ClientOptions::default().with_experimental_rename(false))
         .enable_rename_dynamic_registration(true)
-        .build()?
-        .wait_until_workspaces_are_initialized()?;
+        .build()
+        .wait_until_workspaces_are_initialized();
 
     // The `Drop` implementation will make sure that the client did not receive any registration
     // request.
@@ -525,10 +525,10 @@ fn register_multiple_capabilities() -> Result<()> {
         )
         .enable_rename_dynamic_registration(true)
         .enable_diagnostic_dynamic_registration(true)
-        .build()?
-        .wait_until_workspaces_are_initialized()?;
+        .build()
+        .wait_until_workspaces_are_initialized();
 
-    let (_, params) = server.await_request::<RegisterCapability>()?;
+    let (_, params) = server.await_request::<RegisterCapability>();
     let registrations = params.registrations;
 
     assert_eq!(registrations.len(), 2);
