@@ -21,7 +21,7 @@ use ty_python_semantic::types::{UNDEFINED_REVEAL, check_types};
 use ty_python_semantic::{
     Module, Program, ProgramSettings, PythonEnvironment, PythonPlatform, PythonVersionSource,
     PythonVersionWithSource, SearchPath, SearchPathSettings, SysPrefixPathOrigin, list_modules,
-    resolve_module,
+    resolve_module_confident,
 };
 
 mod assertion;
@@ -259,7 +259,10 @@ fn run_test(
             }
 
             assert!(
-                matches!(embedded.lang, "py" | "pyi" | "python" | "text" | "cfg"),
+                matches!(
+                    embedded.lang,
+                    "py" | "pyi" | "python" | "text" | "cfg" | "pth"
+                ),
                 "Supported file types are: py (or python), pyi, text, cfg and ignore"
             );
 
@@ -296,7 +299,16 @@ fn run_test(
                 full_path = new_path;
             }
 
-            db.write_file(&full_path, &embedded.code).unwrap();
+            let temp_string;
+            let to_write = if embedded.lang == "pth" && !embedded.code.starts_with('/') {
+                // Make any relative .pths be relative to src_path
+                temp_string = format!("{src_path}/{}", embedded.code);
+                &*temp_string
+            } else {
+                &*embedded.code
+            };
+
+            db.write_file(&full_path, to_write).unwrap();
 
             if !(full_path.starts_with(&src_path)
                 && matches!(embedded.lang, "py" | "python" | "pyi"))
@@ -350,6 +362,20 @@ fn run_test(
         vec![]
     };
 
+    // Make any relative extra-paths be relative to src_path
+    let extra_paths = configuration
+        .extra_paths()
+        .unwrap_or_default()
+        .iter()
+        .map(|path| {
+            if path.is_absolute() {
+                path.clone()
+            } else {
+                src_path.join(path)
+            }
+        })
+        .collect();
+
     let settings = ProgramSettings {
         python_version: PythonVersionWithSource {
             version: python_version,
@@ -360,7 +386,7 @@ fn run_test(
             .unwrap_or(PythonPlatform::Identifier("linux".to_string())),
         search_paths: SearchPathSettings {
             src_roots: vec![src_path],
-            extra_paths: configuration.extra_paths().unwrap_or_default().to_vec(),
+            extra_paths,
             custom_typeshed: custom_typeshed_path.map(SystemPath::to_path_buf),
             site_packages_paths,
             real_stdlib_path: None,
@@ -552,7 +578,9 @@ struct ModuleInconsistency<'db> {
 fn run_module_resolution_consistency_test(db: &db::Db) -> Result<(), Vec<ModuleInconsistency<'_>>> {
     let mut errs = vec![];
     for from_list in list_modules(db) {
-        errs.push(match resolve_module(db, from_list.name(db)) {
+        // TODO: For now list_modules does not partake in desperate module resolution so
+        // only compare against confident module resolution.
+        errs.push(match resolve_module_confident(db, from_list.name(db)) {
             None => ModuleInconsistency {
                 db,
                 from_list,
